@@ -4,7 +4,7 @@
 
     Cart
 
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) LTD
+    :copyright: (c) 2010-2013 by Openlabs Technologies & Consulting (P) LTD
     :license: GPLv3, see LICENSE for more details
 '''
 from decimal import Decimal
@@ -255,7 +255,8 @@ class Cart(ModelSQL):
             'is_cart': True,
             'state': 'draft',
             'website': site.id,
-            'nereid_user': user.id
+            'nereid_user': user.id,
+            'warehouse': request.nereid_website.warehouse.id,
         }
         return sale_obj.create(sale_values)
 
@@ -277,6 +278,11 @@ class Cart(ModelSQL):
         if request.method == 'POST' and form.validate():
             cart = self.open_cart(create_order=True)
             action = request.values.get('action', 'set')
+            if form.quantity.data <= 0:
+                flash(
+                    _('Be sensible! You can only add real quantities to cart')
+                )
+                return redirect(url_for('nereid.cart.view_cart'))
             self._add_or_update(
                 cart.sale.id, form.product.data, form.quantity.data, action
             )
@@ -323,7 +329,8 @@ class Cart(ModelSQL):
             for key, value in values.iteritems():
                 if '.' not in key:
                     new_values[key] = value
-
+                if key == 'taxes' and value:
+                    new_values[key] = [('set', value)]
             return sale_line_obj.write(order_line.id, new_values)
         else:
             values = {
@@ -341,6 +348,8 @@ class Cart(ModelSQL):
             for key, value in values.iteritems():
                 if '.' not in key:
                     new_values[key] = value
+                if key == 'taxes' and value:
+                    new_values[key] = [('set', value)]
             return sale_line_obj.create(new_values)
 
     def delete_from_cart(self, line):
@@ -444,7 +453,7 @@ Website()
 
 
 @login.connect
-def login_event_handler(website_obj):
+def login_event_handler(website_obj=None):
     """This method is triggered when a login event occurs.
 
     When a user logs in, all items in his guest cart should be added to his
@@ -475,7 +484,7 @@ def login_event_handler(website_obj):
     # Find the guest cart
     ids = cart_obj.search([
         ('sessionid', '=', session.sid),
-        ('user', '=', current_app.guest_user),
+        ('user', '=', request.nereid_website.guest_user.id),
         ('website', '=', request.nereid_website.id)
         ], limit=1)
     if not ids:
